@@ -88,8 +88,14 @@ class BigQueryProfileExtractor(BigQueryExtractor):
 
         datasets = [self._profile_table(client, table, jobs) for table in tables]
 
+        counter = 0
         while jobs:
-            logger.info("waiting for jobs to finish ... sleeping for 1s")
+            finished = len(datasets) - len(jobs)
+            if counter % 10 == 0:
+                logger.info(
+                    f"{finished} job done, waiting for {len(jobs)} jobs to finish ..."
+                )
+            counter += 1
             sleep(1)
 
         return datasets
@@ -101,11 +107,30 @@ class BigQueryProfileExtractor(BigQueryExtractor):
         jobs: Set[QueryJob],
     ) -> Dataset:
         def job_callback(job: QueryJob, schema: DatasetSchema, dataset: Dataset):
+            exception = job.exception()
             # The profiling result should only have one row
-            assert job.result().total_rows == 1
+            if job.result().total_rows != 1:
+                logger.warning(
+                    f"Skip {table}, the profiling result is more than one row"
+                )
+            elif exception:
+                logger.error(f"Skip {table}, Google Client error: {exception}")
+            else:
+                try:
+                    results = [res for res in next(job.result())]
+                    BigQueryProfileExtractor._parse_result(results, schema, dataset)
+                    1 / 0
+                except AssertionError as error:
+                    logger.error(f"Assertion failed during process results, {error}")
+                except StopIteration as error:
+                    logger.error(f"Invalid result, {error}")
+                except (IndexError, ValueError, TypeError) as error:
+                    logger.error(f"Unknown error during process results, {error}")
+                except BaseException as error:
+                    jobs.remove(job.job_id)
+                    raise error
 
-            results = [res for res in next(job.result())]
-            BigQueryProfileExtractor._parse_result(results, schema, dataset)
+            # Always remove job from the set, because the job(future) is fulfill
             jobs.remove(job.job_id)
 
         dataset = BigQueryProfileExtractor._init_dataset(
@@ -138,7 +163,7 @@ class BigQueryProfileExtractor(BigQueryExtractor):
             data_type = field.native_type
             nullable = field.nullable
 
-            if data_type != "RECORD":
+            if not BigQueryProfileExtractor._is_complex(data_type):
                 query.append(f", COUNT(DISTINCT `{column}`)")
 
             if nullable:
@@ -172,7 +197,7 @@ class BigQueryProfileExtractor(BigQueryExtractor):
             nullable = field.nullable
 
             unique_values = None
-            if data_type != "RECORD":
+            if not BigQueryProfileExtractor._is_complex(data_type):
                 unique_values = float(results[index])
                 index += 1
 
@@ -204,7 +229,7 @@ class BigQueryProfileExtractor(BigQueryExtractor):
                 )
             )
 
-        assert index == len(results)
+        assert index == len(results), "index should match number of results"
 
     # See https://cloud.google.com/bigquery/docs/reference/standard-sql/data-types#numeric_types
     @staticmethod
@@ -225,6 +250,13 @@ class BigQueryProfileExtractor(BigQueryExtractor):
         ]
         return data_type in numeric_types
 
+    @staticmethod
+    def _is_complex(data_type: str) -> bool:
+        # https://cloud.google.com/bigquery/docs/reference/standard-sql/data-types#groupable_data_types
+        return data_type in ("RECORD", "JSON", "GEOGRAPHY") or data_type.startswith(
+            "ARRAY"
+        )
+
     @staticmethod
     def _init_dataset(full_name: str) -> Dataset:
         dataset = Dataset()
